@@ -92,6 +92,15 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
       IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
   #Código para actualizar valores: if isinstance(element[1], sy.Expr):element = [element[0],element[1].subs(c_componente[0],c_componente[1])]
 
+def E(expr,color ="red"):
+  if isinstance(expr,sympy.core.relational.Equality):#Si tenemos una igualdad
+    izquierda = expr.args[0]
+    derecha = expr.args[1]
+    texto = latemix(izquierda) + " = " + latemix(derecha)
+    return IPython.display.Latex(texto)
+  elif isinstance(expr,list):#Si tenemos un componente
+    texto = sy.latex(expr[0]) + " = " + latemix(expr[1])
+    return IPython.display.Latex(texto)
 
 #def E(expr,color = "red"):
 #  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
